@@ -301,7 +301,7 @@ class Sublist(list):
             iterator = range(start, end, step)
         else:
             step = 1
-            iterator = range(start, step, end)
+            iterator = range(start, end, step)
 
         # add the rest of the list to out
         for i in iterator:
@@ -318,6 +318,31 @@ class Sublist(list):
         """
         return Sublist(self.index(x) if x in self else -1 for x in pattern)
 
+    @staticmethod
+    def group_multi(in_list):
+        """
+        Method to group all numbers that occur together in any piece-wise-list manner or
+        in other words find all connected components in a graph
+        example: input [[2,4],[5,6,7,8,10],[3,9,12,4],[14,12],[99,100,101],[104,3],[405,455,456],[302,986,2]]
+        will be grouped to [[2, 3, 4, 9, 12, 14, 104, 302, 986],[5, 6, 7, 8, 10],[99, 100, 101],[405, 455, 456]]
+        :param in_list: List of lists
+        :return: list of lists
+        """
+        first_chunk, *rest_chunks = in_list
+
+        other = []
+        for chunk in rest_chunks:
+            if len(set(first_chunk) & set(chunk)) > 0:
+                first_chunk = set(first_chunk) | set(chunk)
+            else:
+                other.append(chunk)
+        rest_chunks = other
+
+        if len(rest_chunks) > 0:
+            return [list(first_chunk)] + Sublist.group_multi(rest_chunks)
+        else:
+            return [first_chunk]
+
     @staticmethod
     def hist(var_list,
              nbins=20,
@@ -325,6 +350,7 @@ class Sublist(list):
 
         """
         Method to generate a histogram from a list of numbers
+        :param var_list: List of numbers
         :param nbins: Number of bins to group the numbers in a list
         :param minmax: Tuple of minimum and maximum values to be used
                        as criteria of inclusion
@@ -703,10 +729,12 @@ class Handler(object):
 
     def add_to_filename(self,
                         string=None,
+                        new_extension=None,
                         timestamp=False):
         """
         Method to append a string to a filename, before the .xxx extension
         :param string: String to append
+        :param new_extension:
         :param timestamp: If timestamp (upto seconds) should be added to a filename, before the .xxx extension
                           This can be used in addition to the string
         :return:
@@ -726,7 +754,10 @@ class Handler(object):
 
         file_name += string
 
-        self.basename = file_name + file_ext
+        if new_extension is not  None:
+            self.basename = file_name + new_extension
+        else:
+            self.basename = file_name + file_ext
 
         if self.dirname is not None:
             return self.dirname + self.sep + self.basename
@@ -1182,6 +1213,7 @@ class Handler(object):
                     for line in f:
                         if counter == 0:
                             colnames = list(elem.strip() for elem in line.split(','))
+                            lines.append(colnames)
                         elif len(line.split(',')) != len(colnames):
                             err_counter += 1
                         else:
@@ -1192,6 +1224,7 @@ class Handler(object):
                     for line in f:
                         if counter == 0:
                             colnames = list(elem.strip() for elem in line.split(','))
+                            lines.append(colnames)
                         elif len(line.split(',')) != len(colnames):
                             err_counter += 1
                         elif counter <= line_limit:
@@ -1222,6 +1255,7 @@ class Handler(object):
                     for il, line in enumerate(f):
                         if counter == 0:
                             colnames = list(elem.strip() for elem in line.split(','))
+                            lines.append(colnames)
                             counter += 1
                         elif len(line.split(',')) != len(colnames):
                             err_counter += 1
@@ -1964,5 +1998,4 @@ class Timer:
             sys.stdout.write("Time it took to run {}: {}\n".format(func.__name__, t))
             return val
 
-        return wrapper
-
+        return wrapper
\ No newline at end of file
