@@ -1,3 +1,4 @@
+import numpy
 import numpy as np
 from geosoup.common import Handler, Opt, Sublist
 from geosoup.exceptions import ImageProcessingError, ObjectNotFound
@@ -326,16 +327,44 @@ class Raster(object):
                 if verbose:
                     Opt.cprint('Overview written to disk!')
 
+    def band_histogram(self,
+                       band=0,
+                       bins=None,
+                       bin_range=None):
+        """
+        Method to compute histogram for a raster band. Uses numpy histogram function.
+        :param band: Band index, starts from 0
+        :param bins: If bins is an int, it defines the number of equal-width bins
+                    in the given range (10, by default). If bins is a sequence,
+                    it defines a monotonically increasing array of bin edges,
+                    including the rightmost edge, allowing for non-uniform bin widths.
+        :param bin_range: The lower and upper range of the bins. If not provided,
+                    range is simply (a.min(), a.max()). Values outside the range are ignored.
+                    The first element of the range must be less than or equal to the second.
+                    range affects the automatic bin computation as well. While bin width
+                    is computed to be optimal based on the actual data within range,
+                    the bin count will fill the entire range including portions containing no data.
+        """
+        self.read_array(band_order=[band],
+                        nodatavalue=self.nodatavalue)
+
+        array = self.array if self.nodatavalue is None else self.array[self.array != self.nodatavalue]
+
+        histogram, bin_edges = np.histogram(array[~np.isnan(array)],
+                                            bins=bins,
+                                            range=bin_range)
+
+        return histogram, bin_edges
+
     def add_overviews(self,
                       resampling='nearest',
                       overviews=None,
                       **kwargs):
         """
         Method to create raster overviews
-        :param resampling:
-        :param overviews:
-        :param kwargs:
-        :return:
+        :param resampling: nearest (default),average,rms,gauss,cubic,cubicspline,lanczos,average_magphase,mode
+        :param overviews: A list of integral overview levels to build
+        :param kwargs: arguments for making overviews: e.g.: bigtiff='yes', compress='lzw', etc.
         """
 
         fileptr = gdal.Open(self.name, 0)
@@ -907,8 +936,8 @@ class Raster(object):
                 xmin, xmax, ymin, ymax = bound_coords
             elif coords_type == 'crs':
                 _xmin, _xmax, _ymin, _ymax = bound_coords
-                coords_list = [(_xmin, _ymax), (_xmax, _ymax), (_xmax, _ymin), (_xmin, _ymin)]
-                coords_locations = np.array(self.get_locations(coords_list,
+                vertices = [(_xmin, _ymax), (_xmax, _ymax), (_xmax, _ymin), (_xmin, _ymin)]
+                coords_locations = np.array(self.get_locations(vertices,
                                                                (self.transform[1], self.transform[5]),
                                                                (self.transform[0], self.transform[3])))
                 xmin, xmax, ymin, ymax = \
@@ -1024,7 +1053,7 @@ class Raster(object):
         :return: numpy array
         """
 
-        if edge_buffer is None:
+        if edge_buffer is None or edge_buffer == (None, None):
             edge_buffer_x, edge_buffer_y = 0, 0
         else:
             edge_buffer_x, edge_buffer_y = edge_buffer
@@ -2305,5 +2334,4 @@ class MultiRaster:
                 ras.add_overviews()
 
         if return_datasource:
-            return warp_datasource
-
+            return warp_datasource
\ No newline at end of file
