@@ -398,7 +398,7 @@ class Vector(object):
         :param _return: Type of response to return ('code' or 'name')
         :return: string
         """
-        if type(inp_str).__name__ != 'str':
+        if type(inp_str) != str:
             return Vector.ogr_data_type(inp_str, _return)
         else:
             try:
@@ -751,6 +751,55 @@ class Vector(object):
 
             out_datasource = out_driver = None
 
+    def write_geoms_as_files(self,
+                             name_attribute=None,
+                             out_folder=None,
+                             verbose=False):
+        """
+        Method to divide a multi geometry shapefile into multiple shapefiles
+        :param name_attribute: Attribute to use for naming the output files
+        :param out_folder: Output file folder
+        :param verbose: If some steps whole be verbose
+        """
+
+        if out_folder is None:
+            out_folder = Handler(self.filename).dirname
+
+        counter = None
+
+        for i, wkt_geom in enumerate(self.wktlist):
+
+            file_suffix = '_geom_{}.shp'.format(str(i + 1)) if (name_attribute is None
+                                                                or name_attribute not in self.attr_def) \
+                else '_{}.shp'.format(str(self.attributes[i][name_attribute].replace(' ', '_')))
+
+            filename = out_folder + Handler().sep + Handler(self.filename).basename.replace('.shp', '') + \
+                file_suffix
+
+            if verbose:
+                sys.stdout.write('Writing {}...'.format(filename))
+
+            new_vec = Vector(filename=filename,
+                             name=Handler(filename).basename,
+                             spref=self.spref,
+                             geom_type=OGR_GEOM_DEF[self.type],
+                             verbose=verbose)
+
+            new_vec.wktlist = [self.wktlist[i]]
+            new_vec.type = self.type
+            new_vec.attr_def = self.attr_def
+            new_vec.attributes = [self.attributes[i]]
+            new_vec.nfeat = 1
+            new_vec.fields = self.fields
+            new_vec.datasource = None
+
+            new_vec.write_vector(outfile=filename)
+            counter = i
+
+        if verbose:
+            sys.stdout.write('\nWritten {} files from {}.\n'.format(str(counter + 1),
+                                                                    Handler(self.filename).basename))
+
     def get_intersecting_vector(self,
                                 query_vector,
                                 filter_query=False,
@@ -882,10 +931,6 @@ class Vector(object):
         :return: Reprojected vector object
         """
 
-        vector = Vector()
-        vector.type = self.type
-        vector.nfeat = self.nfeat
-
         if destination_spatial_ref is None:
             destination_spatial_ref = osr.SpatialReference()
 
@@ -904,7 +949,12 @@ class Vector(object):
             else:
                 raise ValueError("Destination spatial reference not specified")
 
-        vector.spref = destination_spatial_ref
+        vector = Vector(geom_type=OGR_GEOM_DEF[self.type],
+                        spref=destination_spatial_ref,
+                        name=Handler(self.name).add_to_filename('_reproj'))
+
+        vector.filename = Handler(self.filename).add_to_filename('_reproj')
+        vector.nfeat = self.nfeat
         vector.spref_str = destination_spatial_ref.ExportToWkt()
 
         # get source spatial reference from Spatial reference WKT string in self
@@ -914,25 +964,11 @@ class Vector(object):
         transform_tool = osr.CoordinateTransformation(source_spatial_ref,
                                                       destination_spatial_ref)
 
-        # Create a memory layer
-        memory_driver = ogr.GetDriverByName('Memory')
-        vector.datasource = memory_driver.CreateDataSource('out')
-
-        # create a layer in memory
-        vector.layer = vector.datasource.CreateLayer('temp',
-                                                     srs=source_spatial_ref,
-                                                     geom_type=self.type)
-
-        # initialize new feature list
-        vector.features = list()
-        vector.fields = list()
-        vector.name = self.name
-
         # input layer definition
         in_layer_definition = self.layer.GetLayerDefn()
 
         # add fields
-        for i in range(0, in_layer_definition.GetFieldCount()):
+        for i in range(in_layer_definition.GetFieldCount()):
             field_definition = in_layer_definition.GetFieldDefn(i)
             vector.layer.CreateField(field_definition)
             vector.fields.append(field_definition)
@@ -940,8 +976,8 @@ class Vector(object):
         # layer definition with new fields
         temp_layer_definition = vector.layer.GetLayerDefn()
 
-        vector.wktlist = list()
         vector.attributes = self.attributes
+        vector.attr_def = self.attr_def
 
         # convert each feature
         for feat in self.features:
@@ -957,15 +993,13 @@ class Vector(object):
             temp_feature.SetGeometry(temp_geom)
 
             # fill geometry fields
-            for i in range(0, temp_layer_definition.GetFieldCount()):
+            for i in range(temp_layer_definition.GetFieldCount()):
                 field_definition = temp_layer_definition.GetFieldDefn(i)
                 temp_feature.SetField(field_definition.GetNameRef(), feat.GetField(i))
 
-            # add the feature to the shapefile
+            # add the feature to the new vector
             vector.layer.CreateFeature(temp_feature)
-
             vector.features.append(temp_feature)
-            vector.epsg = epsg
 
         if return_vector:
             return vector
@@ -1411,5 +1445,4 @@ class Vector(object):
             return 0
         except Exception as e:
             sys.stdout.write(e.args[0] + '\n')
-            return 1
-
+            return 1
\ No newline at end of file
